<?php
/**
* WPPIZZA_MARKUP_PAGES Class
*
* @package     WPPIZZA
* @subpackage  Opening times
* @copyright   Copyright (c) 2015, Oliver Bach
* @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
* @since       3.0
*
*/
if ( ! defined( 'ABSPATH' ) ) exit;/*Exit if accessed directly*/

/* ================================================================================================================================= *
*
*
*
*	CLASS - WPPIZZA_MARKUP_PAGES
*
*
*
* ================================================================================================================================= */

class WPPIZZA_MARKUP_PAGES{

	/******************************************************************************
	*
	*
	*	[construct]
	*
	*
	*******************************************************************************/
	function __construct() {
		
		/* get title and order details on thank you page */
		add_action('wp', array($this, 'thankyou_order_info'));		
		
		/** add some localized js variables (validation rules)*/
		add_filter('wppizza_filter_js_localize',array($this, 'localize_js_orderpage_validation_rules'));

		/** thank you page, replace title/content **/
		add_filter('the_title', array($this, 'thankyoupage_title'), 10, 2);
		add_filter('the_content', array($this, 'thankyoupage_content'), 10, 2);
	}

	/******************************************************************************
	*
	*
	*	[methods]
	*
	*
	*******************************************************************************/
	/***************************************
		[get order details once to display right title and info
		on thank you page (instead of running the query 2x) ]
	***************************************/
	function thankyou_order_info($param, $type = 'thankyoupage'){
		global $post, $wppizza_options;
		

		/*
			get relevant title and content on thank you page 
		*/
		if(is_object($post) && $wppizza_options['order_settings']['orderpage'] == $post->ID && ( isset($_GET[WPPIZZA_TRANSACTION_GET_PREFIX]) || isset($_GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX]) ) ){ 
						
			
			/* 
				get order from transaction prefix hash 
			*/
			if(isset($_GET[WPPIZZA_TRANSACTION_GET_PREFIX])){
				$results = WPPIZZA()->db->fetch_order_details(false, false, $_GET[WPPIZZA_TRANSACTION_GET_PREFIX], array('COMPLETED', 'FAILED', 'INPROGRESS', 'PENDING', 'AUTHORIZED', 'CAPTURED', 'CANCELLED', 'UNCONFIRMED' ), false);
			}
			/* 
				get order from cancel prefix hash
			*/
			if(isset($_GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX])){
				$results = WPPIZZA()->db->fetch_order_details(false, false, $_GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX], array('COMPLETED', 'FAILED', 'INPROGRESS', 'PENDING', 'AUTHORIZED', 'CAPTURED', 'CANCELLED', 'UNCONFIRMED'  ), false);
			}
			
			/* 
				format results 
			*/
			if($results){
				$results_formatted = WPPIZZA()->order->results_formatted($type, $results['orders'][0]);	
				$payment_status = $results_formatted['sections']['ordervars']['payment_status']['value'];	
			}
	
			/********************
				get/set page title
			********************/			
						
			/* generic | unknown | failed */
			$this -> thankyoupage_title = $wppizza_options['localization']['generic_error_label'];
			
			
			/* cancelled */
			if((!empty($payment_status) && $payment_status == 'CANCELLED') || isset($_GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX]) ){
				$this -> thankyoupage_title = $wppizza_options['localization']['order_cancelled'];	
			}

			/* in progress - empty title as it's already displayed in th ebody*/
			if(!empty($payment_status) && $payment_status == 'INPROGRESS'){
				$this -> thankyoupage_title = '&nbsp;';
			}

			/* unconfirmed */
			if(!empty($payment_status) && $payment_status == 'UNCONFIRMED'){
				$this -> thankyoupage_title = $wppizza_options['localization']['order_unconfirmed'];	
			}

			/* completed */
			if(!empty($payment_status) && $payment_status == 'COMPLETED'){
				$this -> thankyoupage_title = $wppizza_options['localization']['thank_you'];	
			}	
			
			/* specifically set to error */
			if(isset($_GET['e'])){
				$this -> thankyoupage_title = $wppizza_options['localization']['generic_error_label'];
			}
			
			/********************
				get/set order results formatted
			********************/			
			$this -> thankyoupage_results_formatted = !empty($results_formatted) ? $results_formatted : false;			
		}


	return;
	}
	
	/***************************************
		[change title in thank you page after order]
	***************************************/
	function thankyoupage_title($title, $post_id = null) {
		global $wppizza_options;
		$orderpage_id = $wppizza_options['order_settings']['orderpage'];
		
		if($orderpage_id == $post_id && is_page( $post_id ) && !empty($this -> thankyoupage_title)){
			$title = $this -> thankyoupage_title;
		}

	return $title;
	}

	/***************************************
		[change content in page of thank you page after order
		- if $_GET['wpptx'] or $_GET['wppcltx']   ]
	***************************************/
	function thankyoupage_content($content){
		global $wppizza_options, $post;
		$orderpage_id = $wppizza_options['order_settings']['orderpage'];
				
		if ( $orderpage_id == $post->ID && is_page( $post->ID )  && isset($_GET[WPPIZZA_TRANSACTION_GET_PREFIX]) ) {
			$content = self::markup('thankyoupage');
	    }
	
		if ( $orderpage_id == $post->ID && is_page( $post->ID )  && isset($_GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX]) ) {
			$content = self::markup('ordercancelled');
	    }

	return $content;
	}

	/***************************************
		[add some localized js variables for validations]
		orderpage only
	***************************************/
	function localize_js_orderpage_validation_rules($localize){
		/* bail if not orderpage and no orderpage widget*/
		if(!wppizza_is_orderpage() && !wppizza_has_orderpage_widget()){
			return $localize;
		}

		global $wppizza_options;

		/*****************************
			validation rules, as set in formfields
		*****************************/
		$validate_rules = array();
		/** forced to orderpage (because it is parameter) */
		foreach(WPPIZZA()->helpers->enabled_formfields(false, true, false, 'orderpage') as $key=>$value){
			$rules=$value['validation'];
			foreach($rules as $rule_key=>$rule_value)
			if($rule_key!='default'){
				$validate_rules[$key][$rule_key] = $rule_value;
			}
		}
		/*
			add to localized script
		*/
		$localize['validate']['rules'] = $validate_rules;

		/*****************************
			validation error messages
		*****************************/
		$validate_error['email'] = $wppizza_options['localization']['required_field_email'];
		$validate_error['required'] = $wppizza_options['localization']['required_field'];
		$validate_error['decimal'] = $wppizza_options['localization']['required_field_decimal'];
		/* decode any entities */
		foreach($validate_error as $jsmKey => $jsMessage){
			$validate_error[$jsmKey] = wppizza_decode_entities($jsMessage);	
		}		
		
		/*
			add to localized script
		*/
		$localize['validate']['error'] = $validate_error;

	return	$localize;
	}
	/***************************************
		[apply attributes]
	***************************************/
	function markup($type, $atts = null){
		global $wppizza_options;
		/* merge localization */
		$txt = $wppizza_options['confirmation_form']['localization'] + $wppizza_options['localization'];

		/* get session user data */
		$user_session = WPPIZZA()->session->get_userdata();


		/**get markup**/
		if($type == 'orderpage'){
			$markup = self::order_page($type, $atts, $txt, $user_session);
		}

		/**get markup**/
		if($type == 'confirmationpage'){
			$markup = self::confirmation_page($type, $atts, $txt, $user_session);
		}

		/**get markup**/
		if($type == 'thankyoupage'){
			$markup = self::thankyou_page($type, $atts, $txt, $user_session);
		}
		
		/**get markup**/
		if($type == 'ordercancelled'){
			$markup = self::cancelled_page($type, $atts, $txt, $user_session);
		}

		/**get markup**/
		if($type == 'orderhistory'){
			$markup = self::orderhistory_page($type, $atts, $txt, $user_session);
		}


		return $markup;
	}

	/***************************************

		[orderpage]

	***************************************/
	function order_page($type, $atts , $txt, $user_session){
		global $wppizza_options;

		/* get order details form session hash and get formatted output */
		$results = WPPIZZA()->db->fetch_order_details(false, false, $user_session['wppizza_hash'],'INITIALIZED');
		$order_results = WPPIZZA()->order->results_formatted($type, $results['orders'][0], true);

		/* show formfields from session as customer_ini might not have been set yet */
		$order_formatted = $order_results['sections'];/* for consistency with carts etc */
		$order_formatted['checkout_parameters'] = $order_results['checkout_parameters'];
		$cart_empty = empty($order_formatted['order']['items']) ? true :  false ;
		$shop_open = wppizza_is_shop_open();
		$can_checkout = !empty($order_formatted['checkout_parameters']['can_checkout']) ? true : false;
		$nocart  = !empty($atts['nocart']) ?  true : false;
		//$is_widget  = !empty($atts['is_widget']) ?  true : false;/* not really in use here, but might be useful one day */

				
		/*
			ids'|classes
		*/
		$id = ''.WPPIZZA_PREFIX.'-order-wrap-'.$type.'';
		$formid = ''.WPPIZZA_PREFIX.'-send-order';
		$class = ''.WPPIZZA_PREFIX.'-order-wrap';
		if(!empty($order_formatted['checkout_parameters']['is_pickup'])){
		$class .= ' '.WPPIZZA_PREFIX.'-order-ispickup';	
		}
		
		
		$class_shop_closed = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-shop-closed';
		$class_cart_empty = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-cart-empty';

		$order_fieldset_id = ''.WPPIZZA_PREFIX.'-order-details';
		$order_fieldset_class = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-order-details';

		$personal_fieldset_id = ''.WPPIZZA_PREFIX.'-personal-details';
		$personal_fieldset_class = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-personal-details';

		$payment_methods_fieldset_id = ''.WPPIZZA_PREFIX.'-payment-methods';
		$payment_methods_fieldset_class = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-payment-methods';


		/**************************************
			login form - will never get here if no items in cart anyway
		**************************************/
		$login_form = WPPIZZA()->user->login_form();// uses markup/global/login.php

		/**************************************
			order
		**************************************/
		if(!$nocart){/* if cart not disabled by 'nocart=1|true' in shortcode/widget */	
			/*
				itemised items table
			*/  		
	  		$order_details_itemised = WPPIZZA() -> markup_maincart -> itemised_markup($order_formatted, $type);
			
			/*
				subtotals/summary table
			*/
			$order_details_summary = WPPIZZA() -> markup_maincart -> summary_markup($order_formatted, $type);
			/*
				pickup / delivery note
			*/
			$order_details_pickup_note = self::pickup_note_markup($order_formatted, $type);
			/*
		  		pickup checkbox
			*/
			$order_details_pickup_choices = WPPIZZA() -> markup_pickup_choice -> attributes($atts, $type);
		}else{
			/** avoid php notices **/
			$order_details_itemised = '';
			$order_details_summary = '';
			$order_details_pickup_note = '';
			$order_details_pickup_choices = '';
			
		}
		/*************************************
			personal_details
		*************************************/
		/*
			user input fields
		*/
		$personal_details = WPPIZZA()->user->formfields_inputs($order_formatted['customer']);
		/*
			user update info - within fieldset. might be an empty string if certain conditions are not met
		*/
		$user_profile = WPPIZZA()->user->profile_options();


		/**************************************
			gateways buttons
		**************************************/
		$payment_methods ='';
		if($can_checkout){/* will also have checked if there are any gateways enabled */
			$payment_methods = WPPIZZA()->gateways->markup();
		}

		/**************************************
			submit button provided one can actually checkout
		**************************************/
		$submit_button = '';
		if($can_checkout){
			$button_class = array();
			$button_class[] = 'submit';
			$button_class[] = !empty($wppizza_options['confirmation_form']['confirmation_form_enabled']) ? ''.WPPIZZA_PREFIX.'-confirm-order' : ''.WPPIZZA_PREFIX.'-ordernow';/** are we using a confirmation form too ?**/
			$button_class = implode(' ', $button_class);

			/** 
				use image instead of button 
			**/
			$submit_image = apply_filters('wppizza_filter_submit_as_image', '');			
			if(!empty($submit_image)){
				$submit_button .='<div id="'.WPPIZZA_PREFIX.'-ordernow" class="'. $button_class .' '.WPPIZZA_PREFIX.'-ordernow-img" title="'.$txt['send_order'].'" >';
					$submit_button .='<input type="image" src="'.$submit_image.'" border="0" alt="'.$txt['send_order'].'" />';
				$submit_button .='</div>';
			}else{
				$submit_button .='<input id="'.WPPIZZA_PREFIX.'-ordernow" class="'. $button_class .'" type="submit" style="display:block" value="'.$txt['send_order'].'" />';
			}
			/* add nonce */
			$submit_button .= ''.wp_nonce_field( '' . WPPIZZA_PREFIX . '_nonce_checkout','' . WPPIZZA_PREFIX . '_nonce_checkout',true,false).'';



			/* add cache buster input - in conjunction with js force reloading order page when backpaging after cod order */
			$submit_button .='<input id="'.WPPIZZA_PREFIX.'_no_cache" type="hidden" name="'.WPPIZZA_PREFIX.'_no_cache" value="'.time().'" />';
		}

		/**
			no checkout applies if min order not reached OR no gateway enabled.
			only if min order applues will a note be displayed though
			if there's no gateway enabled, then nothing will show
		**/
		/*
			minimum order required text
		*/
		$minimum_order = WPPIZZA() -> markup_maincart -> minimum_order($order_formatted, $type);


		/*************************************

			markup

		*************************************/
		/*
			ini array
		*/
		$markup = array();
		
		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.order.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.order.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/pages/page.order.php');
		}
		/*
			apply filter if required and implode for output
		*/
				
		$markup = apply_filters('wppizza_filter_pages_order_markup', $markup, $order_formatted );
		
		/* 
			if cart disabled by 'nocart=1|true' shortcode , remove fieldset 
		*/
		if($nocart){
			unset($markup['order_details_']);
			unset($markup['order_details_legend']);
			unset($markup['order_details_itemised']);
			unset($markup['order_details_summary']);
			unset($markup['order_details_pickup_note']);
			unset($markup['order_details_pickup_choices']);
			unset($markup['_order_details']);
		}

		$markup = implode('', $markup);

	return $markup;

	}

	/***************************************

		[confirmation page]

	***************************************/
	function confirmation_page($type, $atts = null, $txt, $user_session){

		/* get order details from db */
		$results = WPPIZZA()->db->fetch_order_details(false, false, $user_session['wppizza_hash'], 'INITIALIZED');

		/* show formfields from session as customer_ini might not have been set yet */
		//set true as well, to also - again - run a $can_checkout check using $order_formatted['checkout_parameters']['can_checkout']. would have performance implications and i think this is overkill for the moment as you would never get to this page without being able to checkout */
		$order_results = WPPIZZA()->order->results_formatted($type, $results['orders'][0]);
		$order_formatted = $order_results['sections'];/* for consistency with carts etc */
		$order_formatted['confirmation'] = $order_results['confirmation'];

		/**get links to order/amend pages*/
		$href_orderpage = wppizza_page_links('orderpage');
		$href_amendorder = wppizza_page_links('amendorderlink');
		/** do we have any confirmation inputs ?*/
		$has_inputs = !empty($order_formatted['confirmation']) ?  true : false;


		/*
			ids'|classes
		*/
		$id = ''.WPPIZZA_PREFIX.'-order-wrap-'.$type.'';
		$class = ''.WPPIZZA_PREFIX.'-order-wrap '.WPPIZZA_PREFIX.'-order-wrap-'.$type.'';
		if(!empty($order_formatted['ordervars']['pickup_delivery']['value']) && $order_formatted['ordervars']['pickup_delivery']['value'] == 'Y'){
		$class .= ' '.WPPIZZA_PREFIX.'-order-ispickup';	
		}		


		$id_form = ''.WPPIZZA_PREFIX.'-send-order';
		$class_form = ''.WPPIZZA_PREFIX.'-order-confirmed';

		$class_legal = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-legal';
		$class_personal_details = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-personal-details';
		$class_payment_method = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-payment-method';

		$id_order_details = ''.WPPIZZA_PREFIX.'-order-details-'.$type.'';
		$class_order_details = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-order-details';

		$id_subtotals_after = ''.WPPIZZA_PREFIX.'-'.$type.'-subtotals-after';





		/***********************

			[markup parameters]

		************************/

		/*
			confirmation form input fields
		*/
		if($has_inputs){
			$confirm_inputs = WPPIZZA()->user->formfields_inputs($order_formatted['confirmation']);
		}
		/*
			personal_details
		*/
			$personal_details= WPPIZZA()->user->formfields_values($order_formatted['customer'], 'confirmationpage');

		/*
			payment-method
		*/
			$payment_method = WPPIZZA()->gateways->markup(true);

		/*
			order-details
		*/
			/* pickup / delivery note */
			$order_details_pickup_note = self::pickup_note_markup($order_formatted, $type);

			/*	order_itemised	*/
			$order_details_itemised = WPPIZZA()->markup_maincart->itemised_markup($order_formatted, $type); /* cart_itemised */

			/*	order_summary */
			$order_details_summary = WPPIZZA()->markup_maincart->summary_markup($order_formatted, $type); /* summary */

		/*
			submit_button
		*/
			$submit_button ='<input id="'.WPPIZZA_PREFIX.'-ordernow" class="submit '.WPPIZZA_PREFIX.'-ordernow" type="submit" style="display:block" value="'.$txt['confirm_now_button'].'" />';
			/* set flag that this is the confirmation page to not override session vars from main order page*/
			$submit_button .='<input type="hidden" name="'.WPPIZZA_PREFIX.'_'.$type.'" value="1" />';
			/* add nonce */
			$submit_button .= ''.wp_nonce_field( '' . WPPIZZA_PREFIX . '_nonce_checkout','' . WPPIZZA_PREFIX . '_nonce_checkout',true,false).'';


		/*************************************

			markup

		*************************************/
		/*
			ini array
		*/
		$markup = array();
		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.confirm-order.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.confirm-order.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/pages/page.confirm-order.php');
		}
		/*
			apply filter if required and implode for output
		*/
		$markup = apply_filters('wppizza_filter_pages_confirmorder_markup', $markup, $order_formatted);
		$markup = implode('', $markup);


	return $markup;



	}
	/***************************************

		[thank you  page]

	***************************************/
	function thankyou_page($type, $atts = null, $txt, $user_session){
		global $wppizza_options, $blog_id ;
		/* 
			also search failed and any progress statusses here to display errors or "waiting page" if necessary 
			furthermore, do not restrict to user id  / 0 / session either. we will display those specifically
		*/
		$show_results = false;
		$is_order = false;
		$is_completed = false;
		$is_inprogress = false;
		$is_unconfirmed = false;
		$is_cancelled = false;
		$order_page_link = '';
		

		if(!empty($this -> thankyoupage_results_formatted)){
			
			//$order_results = WPPIZZA()->order->results_formatted($type, $results['orders'][0]);
			$order_results = $this -> thankyoupage_results_formatted;
			
			
			$order_formatted = $order_results['sections'];/* for consistency with carts etc */
			$show_results = apply_filters('wppizza_filter_showorder_on_thankyou', true);
			
			/** check if this order actually completed and not failed */			
			$is_completed = ($order_formatted['ordervars']['payment_status']['value'] == 'COMPLETED') ? true : false ;
			
			/** in progress statusses, will make page reload a few times**/
			$is_inprogress = (in_array($order_formatted['ordervars']['payment_status']['value'],array('INPROGRESS', 'PENDING', 'AUTHORIZED', 'CAPTURED'))) ? true : false ;

			/** unconfirmed status**/
			$is_unconfirmed = (in_array($order_formatted['ordervars']['payment_status']['value'],array('UNCONFIRMED'))) ? true : false ;

			/** check if it was cancelled **/
			$is_cancelled = (in_array($order_formatted['ordervars']['payment_status']['value'],array('CANCELLED'))) ? true : false ;

						
				
			/** if failed order, return false **/
			$is_order = ($is_completed) ? true : false ;
			/** if failed order, return false **/
			$show_results = ($is_completed) ? true : false ;
			/** 
				if logged in and wp_user_id does not match or 
				not logged and sessionid does not match, do not show full results 
			**/
			if(is_user_logged_in() && $order_formatted['ordervars']['wp_user_id']['value'] != get_current_user_id()){
				$show_results = false;
			}
			if(!is_user_logged_in() && $order_formatted['ordervars']['session_id']['value'] != session_id()){
				$show_results = false;
			}


			/** if failed order, get errors **/
			$errors = ($is_completed || $is_inprogress) ? '' : $order_formatted['ordervars']['display_errors']['value_formatted'];

			/*
				ids'|classes
			*/
			$id = ''.WPPIZZA_PREFIX.'-order-'.$type.'-'.$order_formatted['site']['blog_id']['value_formatted'].'-'.$order_formatted['ordervars']['order_id']['value_formatted'].'';
			$class = ''.WPPIZZA_PREFIX.'-order-wrap '.WPPIZZA_PREFIX.'-order-wrap-'.$type.'';
			if(!empty($order_formatted['ordervars']['pickup_delivery']['value']) && $order_formatted['ordervars']['pickup_delivery']['value'] == 'Y'){
				$class .= ' '.WPPIZZA_PREFIX.'-order-ispickup';	
			}				
			$class_transaction_details = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-transaction-details';
			$class_personal_details = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-personal-details';
			$class_order_details = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-order-details';

		}else{
			/** in case there was an error or order does not exist **/
			$id = ''.WPPIZZA_PREFIX.'-order-'.$type.'-error';
			$class = ''.WPPIZZA_PREFIX.'-order-wrap '.WPPIZZA_PREFIX.'-order-wrap-'.$type.'-error';
			$order_results = false;
			$show_results = false;
			$order_formatted = array();/* as there's no order just return an empty array */
			$errors = '';/* no errors known as db returned no results */
		}
			
		/*
			general error ids'|classes| links
		*/
		$id_errors = ''.WPPIZZA_PREFIX.'-order-errors';
		$class_errors = ''.WPPIZZA_PREFIX.'-order-error';
		$id_noorder = ''.WPPIZZA_PREFIX.'-noorder-'.$type.'';
		$class_noorder = ''.WPPIZZA_PREFIX.'-noorder';
		
		/*
			general processing ids'|classes| links
		*/
		$id_processing = ''.WPPIZZA_PREFIX.'-order-processing';
		$class_processing = ''.WPPIZZA_PREFIX.'-order-processing';
		$id_wait = ''.WPPIZZA_PREFIX.'-processing-'.$type.'';
		$class_wait = ''.WPPIZZA_PREFIX.'-processing';
		$class_order_id = ''.WPPIZZA_PREFIX.'-order-processing-id';
		
		/*
			general unconfirmed ids'|classes| links
		*/
		$id_unconfirmed = ''.WPPIZZA_PREFIX.'-order-unconfirmed';
		$class_unconfirmed = ''.WPPIZZA_PREFIX.'-order-unconfirmed';
					
		if(!$is_completed && !$is_inprogress && !$is_cancelled && !$is_unconfirmed ){
			/**get links to order/amend pages*/
			$order_page_link = wppizza_page_links();
			$order_page_link = '<div class="'.WPPIZZA_PREFIX.'-try-again"><a href="'.$order_page_link['orderpage'].'">'.$txt['failed_payment_try_again_link'].'</a></div>';
		}


		/***********************************************************
			empty cart session when order completed or in progress of completion
		***********************************************************/
		if($is_completed || $is_inprogress || $is_unconfirmed){
			if(!WPPIZZA_DEV_DISABLE_CLEAR_CART){
				WPPIZZA()->session->empty_cart(true);
			}
		}

		/**********************************************************
			showing whole order , not just thank you
		**********************************************************/
		if($show_results){
			/**************************************
				general transaction details
			**************************************/
			$transaction_details = self::order_transaction_details($order_formatted['ordervars'], $type);// uses markup/order/transaction_details.php
			/* pickup / delivery note */
			$order_details_pickup_note = self::pickup_note_markup($order_formatted, $type);//uses markup/global/pages.pickup_note.php
			/*************************************
				personal_details
			*************************************/
			$personal_details = WPPIZZA()->user->formfields_values($order_formatted['customer'], 'thankyoupage');//uses markup/global/formfields.values.php 
			/************************************
				order-details : itemised, summary
			************************************/
			/*	order_itemised	*/
			$order_details_itemised = WPPIZZA()->markup_maincart->itemised_markup($order_formatted, $type); /* cart_itemised - uses markup/order/itemised.php */
			/*	order_summary */
			$order_details_summary = WPPIZZA()->markup_maincart->summary_markup($order_formatted, $type); /* summary - uses markup/order/summary.php */
		}

		/*************************************

			cancelled payment

		*************************************/
		if($is_cancelled){

			/** in case there was an error or order does not exist **/
			$id = ''.WPPIZZA_PREFIX.'-order-cancelled';
			$class = ''.WPPIZZA_PREFIX.'-order-wrap '.WPPIZZA_PREFIX.'-order-wrap-cancelled';

			/*
				[cancelled text]
			*/
			$cancel_text = $txt['order_cancelled_p'];
			/*
				create return to shop link
			*/
			$return_link = '<div class="'.WPPIZZA_PREFIX.'-back-to-shop"><a href="'.site_url().'">'.$txt['label_return_to_shop'].'</a></div>';

			/* 
				cancelled via ipn
			*/
			$cancel_type = 'ipn';

			/*
				ini array
			*/
			$markup = array();
			/*
				get markup
			*/
			if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.cancelled.php')){
				require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.cancelled.php');
			}else{
				require(WPPIZZA_PATH.'templates/markup/pages/page.cancelled.php');
			}

			/*
				apply filter if required and implode for output
			*/
			$markup = apply_filters('wppizza_filter_pages_cancelled_markup', $markup, $order_formatted, $cancel_type);
			$markup = implode('', $markup);
	
	
	
	
		return $markup;
		}

		/*************************************

			processing payment / INPROGRESS

		*************************************/
		if($is_inprogress){

			/** in case there was an error or order does not exist **/
			$id = ''.WPPIZZA_PREFIX.'-order-wrap-processing';
			$class = ''.WPPIZZA_PREFIX.'-order-wrap';
			
			/*
				ini array
			*/
			$markup = array();
			/*
				get markup
			*/
			if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.processing.php')){
				require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.processing.php');
			}else{
				require(WPPIZZA_PATH.'templates/markup/pages/page.processing.php');
			}
			/** order info */
			$markup['order_info_']='<div class="'.$class_order_id.'">';
				$markup['order_info_date']='['.$order_formatted['ordervars']['order_date']['value_formatted'].']';
				$markup['order_info_id']='<br />'.$order_formatted['ordervars']['payment_gateway']['value_formatted'].' - ID:'.$order_formatted['ordervars']['order_id']['value_formatted'].'';
				$markup['order_info_txid']='<br />TXID: '.$order_formatted['ordervars']['transaction_id']['value_formatted'].'';
				$markup['order_info_status']=' - '.$order_formatted['ordervars']['payment_status']['value_formatted'].'';
			$markup['_order_info']='</div>';
			/** add processing js */
			$markup['refresh_page']='<script>setInterval(function(){window.location.reload(true);},5000);</script>';
			
			/*
				apply filter if required and implode for output
			*/
			$markup = apply_filters('wppizza_filter_pages_processing_markup', $markup, $order_formatted);
			$markup = implode('', $markup);
	
	
	
	
		return $markup;
		}
		
		/*************************************

			waiting for confirmation / UNCONFIRMED

		*************************************/
		if($is_unconfirmed){

			/** in case there was an error or order does not exist **/
			$id = ''.WPPIZZA_PREFIX.'-order-wrap-unconfirmed';
			$class = ''.WPPIZZA_PREFIX.'-order-wrap';
			
			/*
				ini array
			*/
			$markup = array();
			/*
				get markup
			*/
			if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.unconfirmed.php')){
				require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.unconfirmed.php');
			}else{
				require(WPPIZZA_PATH.'templates/markup/pages/page.unconfirmed.php');
			}
//			/** order info */
//			$markup['order_info_']='<div class="'.$class_order_id.'">';
//				$markup['order_info_date']='['.$order_formatted['ordervars']['order_date']['value_formatted'].']';
//				$markup['order_info_id']='<br />'.$order_formatted['ordervars']['payment_gateway']['value_formatted'].' - ID:'.$order_formatted['ordervars']['order_id']['value_formatted'].'';
//				$markup['order_info_txid']='<br />TXID: '.$order_formatted['ordervars']['transaction_id']['value_formatted'].'';
//				$markup['order_info_status']=' - '.$order_formatted['ordervars']['payment_status']['value_formatted'].'';
//			$markup['_order_info']='</div>';
//			/** add processing js */
//			$markup['refresh_page']='<script>setInterval(function(){window.location.reload(true);},5000);</script>';
			
			/*
				apply filter if required and implode for output
			*/
			$markup = apply_filters('wppizza_filter_pages_unconfirmed_markup', $markup, $order_formatted);
			$markup = implode('', $markup);
	
	
	
	
		return $markup;
		}		
		
		
		
		
		/*************************************

			markup thank you / failed / unknown

		*************************************/
		/*
			ini array
		*/
		$markup = array();
		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.thankyou.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.thankyou.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/pages/page.thankyou.php');
		}
		/*
			apply filter if required and implode for output
		*/
		$markup = apply_filters('wppizza_filter_pages_thankyou_markup', $markup, $order_formatted);
		$markup = implode('', $markup);


	return $markup;
	}
	/***************************************

		[order cancelled  page]

	***************************************/
	function cancelled_page($type, $atts = null, $txt, $user_session){	

		/***************************************************************
			update db/order to CANCELLED by _GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX]
		****************************************************************/
		/* 
			set db to cancel by hash. will silently not do anything and return false
		 	if hash does not match anything , $_GET will automatically be sanitized
		*/
		$order_cancel = WPPIZZA()->db->cancel_order(false, false, $_GET[WPPIZZA_TRANSACTION_CANCEL_PREFIX]);


		/***************************************************************
			end db cancellation
		****************************************************************/		

		/** in case there was an error or order does not exist **/
		$id = ''.WPPIZZA_PREFIX.'-order-cancelled';
		$class = ''.WPPIZZA_PREFIX.'-order-wrap '.WPPIZZA_PREFIX.'-order-wrap-cancelled';

		/***************************************************************
			if that order does not exist, show error
		****************************************************************/		
		if($order_cancel){
			$cancel_text = $txt['order_cancelled_p'];
		}else{
			$cancel_text = $txt['order_not_found'];
		}
		/*
			create return to shop link
		*/
		$return_link = '<div class="'.WPPIZZA_PREFIX.'-back-to-shop"><a href="'.site_url().'">'.$txt['label_return_to_shop'].'</a></div>';		

		/*
			for consistency use user_session as $order_formatted
		*/
		$order_formatted = $user_session;
		
		/* 
			cancelled via direct link from gateway 
		*/
		$cancel_type = 'link';
		/*************************************

			markup

		*************************************/
		
		/*
			ini array
		*/
		$markup = array();
		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.cancelled.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.cancelled.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/pages/page.cancelled.php');
		}
		/*
			apply filter if required and implode for output
		*/
		$markup = apply_filters('wppizza_filter_pages_cancelled_markup', $markup, $order_formatted, $cancel_type);
		$markup = implode('', $markup);
	
	return $markup;	
	}
	/***************************************

		[users order history page]

	***************************************/
	function orderhistory_page($type, $atts = null, $txt, $user_session){

		$multisite = !empty($atts['multisite']) ? true : false;/* get all orders from all sites in multisite setup ? */
		$maxpp = ( !empty($atts['maxpp']) && (int)$atts['maxpp']>0) ? (int)$atts['maxpp'] : 10;/* how many results per page */		

		/*
			ids'|classes
		*/
		$id = ''.WPPIZZA_PREFIX.'-orders-wrap-'.$type.'';/* wrapper id */
		$class = ''.WPPIZZA_PREFIX.'-orders-wrap '.WPPIZZA_PREFIX.'-order-wrap-'.$type.'';/* wrapper class */
		
		$id_noorders = ''.WPPIZZA_PREFIX.'-noorders-'.$type.'';
		$class_noorders = ''.WPPIZZA_PREFIX.'-noorders';


		/*
			login form
			- only shown if not logged in and registration is enabled in the first place
			show registration disabled here if that is the case and user (typically admin) is not logged in
		*/
		$login_form = WPPIZZA()->user->login_form(true);// uses markup/global/login.php


		/*
			we are not logged in
		*/
		if(!is_user_logged_in()){
			$no_orders = false ;
			$is_logged_in = false ;
			$purchase_history = array();
			$pagination = '';
			$txt['history_no_previous_orders'] = '' ;/* just to make sure if someone takes the if($no_orders) out of the template */
		}
		/*
			we are logged in
		*/		
		if(is_user_logged_in()){

			$is_logged_in = true ;
			$results = WPPIZZA()->db->fetch_order_details(false, false, false, false, get_current_user_id(), $multisite, $maxpp);
			if(!$results){
				$no_orders = true;
				$purchase_history = array();
				$pagination = '';
			}else{
				$no_orders = false;
				$purchase_history = array();
				//$orders = $results['orders'];
				$pagination = self::orderhistory_pagination($results['count'],$maxpp);				
				$txt['history_no_previous_orders'] = '' ;/* just to make sure if someone takes the if($no_orders) out of the template */				

				/* set classes */
				$class_order = ''.WPPIZZA_PREFIX.'-order-wrap '.WPPIZZA_PREFIX.'-order-'.$type.'';
				$class_fieldset = ''.WPPIZZA_PREFIX.'-fieldset '.WPPIZZA_PREFIX.'-transaction-details-'.$type.'';
				$class_legend_span = ''.WPPIZZA_PREFIX.'-dashicon '.WPPIZZA_PREFIX.'-toggle-order-transaction-details dashicons dashicons-plus';
				$class_order_details = ''.WPPIZZA_PREFIX.'-order-details'; 
				$class_transaction_details = ''.WPPIZZA_PREFIX.'-transaction-details';

			
				/* make keys|ids */
				foreach($results['orders'] as $key=>$order){
					/* get order and format */
					$order_results = WPPIZZA()->order->results_formatted($type, $order);
					$order_formatted = $order_results['sections'];/* for consistency with carts etc */
					$order_blog_id = $order_formatted['site']['blog_id']['value_formatted'];
					$order_id = $order_formatted['ordervars']['order_id']['value_formatted'];
					
					/* set id */
					$purchase_history[$key] = array();
					
					$purchase_history[$key]['id'] = ''.WPPIZZA_PREFIX.'-order-'.$type.'-'.$order_blog_id.'-'.$order_id.'';
					
					
					/* might come in useful in filters */
					$purchase_history[$key]['blog_id'] = $order_blog_id;
					$purchase_history[$key]['order_id'] = $order_id;
					
					/* itemised */
					$purchase_history[$key]['order_itemised'] = WPPIZZA()->markup_maincart->itemised_markup($order_formatted, $type);
					/*	order_summary */
					$purchase_history[$key]['order_summary'] = WPPIZZA()->markup_maincart->summary_markup($order_formatted, $type);	
					/* transaction details */
					$purchase_history[$key]['transaction_details'] = self::order_transaction_details($order_formatted['ordervars'], $type);										

				}
			}
		}

		/*************************************

			markup

		*************************************/
		/*
			ini markup array
		*/
		$markup = array();

		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/pages/page.purchase-history.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/pages/page.purchase-history.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/pages/page.purchase-history.php');
		}
		/*
			apply filter if required and implode for output
		*/
		$markup = apply_filters('wppizza_filter_pages_purchasehistory_markup', $markup, $purchase_history);
		$markup = implode('', $markup);


	return $markup;
	}
	/******************************************************************************************************************************




		[helpers]




	******************************************************************************************************************************/
	function orderhistory_pagination($no_of_orders,$maxpp){

		
		/* skip if fewer orders than maxpp */
		if($no_of_orders<=$maxpp){
			$markup = '';
			return $markup ;
		}

		$total_page=ceil($no_of_orders/$maxpp);
		$currentPageLink=get_permalink();
		$current_page = empty($_GET['pg']) ? 1 : (int)$_GET['pg'];


		$markup = array();

		$markup['div_'] = '<div class="'.WPPIZZA_PREFIX.'-history-pagination">';
			/*
				previous link
			*/
			if($current_page>1){
				$link= esc_url_raw(add_query_arg(array('pg' => ($current_page-1)), $currentPageLink ));
				$markup['previous'] = '<a href="'.$link.'" class="'.WPPIZZA_PREFIX.'-history-pagination-previous">'.__('&laquo; Previous Page').'</a>';
			}else{
				$markup['previous_disabled'] = '<a class="'.WPPIZZA_PREFIX.'-history-pagination-previous '.WPPIZZA_PREFIX.'-history-pagination-disabled" disabled="disabled">'.__('&laquo; Previous Page').'</a>';
			}
			/*
				page links
			*/
			for($i=1;$i<=$total_page;$i++){
				if($current_page==$i){
					$markup[$i]= '<a href="javascript:void(0)" class="'.WPPIZZA_PREFIX.'-history-pagination-selected">'.$i.'</a>';
				}else{
					$link= esc_url_raw(add_query_arg(array('pg' => $i), $currentPageLink ));
					$markup[$i]= '<a href="'.$link.'" class="'.WPPIZZA_PREFIX.'-history-pagination-count">'.$i.'</a>';
				}
			}
			/*
				next link
			*/
			if($current_page<$total_page){
				$link= esc_url_raw(add_query_arg(array('pg' => ($current_page+1)), $currentPageLink ));
				$markup['next']= '<a href="'.$link.'" class="'.WPPIZZA_PREFIX.'-history-pagination-next">'.__('Next Page &raquo;').'</a>';
			}else{
				$markup['next_disabled']= '<a class="'.WPPIZZA_PREFIX.'-history-pagination-next '.WPPIZZA_PREFIX.'-history-pagination-disabled" disabled="disabled">'.__('Next Page &raquo;').'</a>';
			}
		$markup['_div'] = '</div>';


		/*
			apply filter if required and implode for output
		*/
		$markup = apply_filters('wppizza_filter_pagination_purchasehistory_markup', $markup);
		$markup = implode('', $markup);

	return $markup;
	}


	/*


		global_details. order date, order id, transation id etc etc

	*/

	function order_transaction_details($order, $type){
		
		/*
			get selected (filterable) parameters
			available keys:
			[wp_user_id] [order_update] [order_delivered] [notes] [payment_gateway] [payment_status] [user_data] 
			[ip_address] [order_date] [order_id] [payment_due] [pickup_delivery] [payment_type] [payment_method] 
			[transaction_id] [total] 				
		*/
		$tx_details_keys = array('order_date','payment_type','transaction_id','order_delivered');
		$tx_details_keys = apply_filters('wppizza_filter_transaction_details', $tx_details_keys, $type);
		
		/*
			omitting empty ones (like order_update) that do not exist yet
			restricted to set keys
		*/
		$transaction_details = array();
		foreach($order as $key=>$parameter){
			if(!empty($parameter['value_formatted']) && in_array($key, $tx_details_keys) ){
				$transaction_details[$key] = array(); 	
				$transaction_details[$key]['class'] = ''.WPPIZZA_PREFIX.'-'.$parameter['class_ident'].'';
				$transaction_details[$key]['label'] = '<label>'.$parameter['label'].'</label>';
				$transaction_details[$key]['value'] = '<span>'.$parameter['value_formatted'].'</span>';
			}
		}
		
		/*************************************

			markup

		*************************************/
		/*
			ini array
		*/
		$markup = array();
		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/order/transaction_details.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/order/transaction_details.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/order/transaction_details.php');
		}

		/*
			apply filter if required (return $markup array will be imploded for output)
		*/
		$markup = apply_filters('wppizza_filter_order_transactiondetails_markup', $markup, $transaction_details, $type);

		$markup = implode('', $markup);	
	
	return $markup;	
	}

	/*
		pickup_note
	*/
	function pickup_note_markup($order_formatted, $type){
		$vals = $order_formatted['ordervars']['pickup_delivery'];

		/* nothing set */
		if(empty($vals['value_formatted'])){return '';}

		$class = ''.WPPIZZA_PREFIX.'-'.$vals['class_ident'].'';
		$pickup_delivery_message = $vals['value_formatted'];

		/*************************************

			markup

		*************************************/
		/*
			ini array
		*/
		$markup = array();
		/*
			get markup
		*/
		if(file_exists( WPPIZZA_TEMPLATE_DIR . '/markup/global/pages.pickup_note.php')){
			require(WPPIZZA_TEMPLATE_DIR.'/markup/global/pages.pickup_note.php');
		}else{
			require(WPPIZZA_PATH.'templates/markup/global/pages.pickup_note.php');
		}
		/*
			apply filter if required and implode for output
		*/
		$markup = apply_filters('wppizza_filter_pages_pickup_note_markup', $markup);
		$markup = implode('', $markup);


	return $markup;
	}
}
?>