<?php
/**
* WPPIZZA_ACTIONS Class
*
* @package     WPPIZZA
* @subpackage  WPPIZZA_ACTIONS
* @copyright   Copyright (c) 2015, Oliver Bach
* @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
* @since       3.0
*
*/
if ( ! defined( 'ABSPATH' ) ) exit;/*Exit if accessed directly*/


/************************************************************************************************************************
*
*
*
*
*
*
************************************************************************************************************************/
class WPPIZZA_MODULE_ORDERHISTORY_ORDERHISTORY{

	private $settings_page = 'orderhistory';/* which admin subpage (identified there by this->class_key) are we adding this to */
	private $section_key = 'orderhistory';/* must be unique */
	private $module_priority = 10;/* display order (priority) of settings in subpage */


	function __construct() {
		/**********************************************************
			[add settings to admin]
		***********************************************************/
		if(is_admin()){

			/** orders on load **/
			add_action('wppizza_admin_orderhistory_results', array( $this, 'order_history_results') );

			/** admin ajax **/
			add_action('wppizza_ajax_admin_'.$this->settings_page.'', array( $this, 'admin_ajax'));

		}
	}
	/*******************************************************************************************************************************************************
	*
	* 	[admin ajax]
	*
	********************************************************************************************************************************************************/
	function admin_ajax($wppizza_options){

		/*************************************************************************************
		*
		*
		*
		*	[show/get orders wppizza->order history]
		*
		*
		*
		***********************************************************************************/
		if($_POST['vars']['field']=='get_orders'){
			/**********set header********************/
			header('Content-type: application/json');
			$order_history = json_decode($this->order_history_markup());

			$obj=array();
			$obj['orders']=$order_history -> markup;
		 	$obj['post']=$_POST;
		 	$obj['values']=$order_history -> values;

			print"".json_encode($obj)."";
			exit();
		}

		if($_POST['vars']['field']=='new_orders'){
			/* get any new orders */
			$new_orders = WPPIZZA() -> db -> get_orders_orderhistory('NEW', -1, 1, 1);
			$results = array();
			$results['new_orders'] = $new_orders['total_orders'];
			print"".json_encode($results)."";
		exit();
		}


		/********************************************
		*
		*
		*	[order history -> refund at gateway]
		*
		*
		********************************************/
		if($_POST['vars']['field']=='refund_at_gateway'){
			
			/*
				check for delete capabilities
			*/
			if(!current_user_can('wppizza_cap_delete_order') || WPPIZZA_DEV_ADMIN_NO_SAVE ){
				/* 
					saving disabled 
				*/
				if(WPPIZZA_DEV_ADMIN_NO_SAVE){
					$obj['update_prohibited'] = __('Update Prohibited', 'wppizza-admin');
					print"".json_encode($obj)."";
				exit();
				}				
				return;
			}			
			
			
			$blog_id = (int)$_POST['vars']['blogid'];
			$order_id = (int)$_POST['vars']['id']; 
			$class = $_POST['vars']['class'];
			/*
				get refunded or completed order
			*/
			$get_order = WPPIZZA() -> db ->fetch_order_details($blog_id, $order_id, false, array('COMPLETED', 'REFUNDED'), false);
			if(empty($get_order)){
				$results['error'] = __('Order not found', 'wppizza-admin');	
				$results['error_message'] = 'Blog ID: '.$blog_id.' Order ID: '.$order_id;
				print"".json_encode($results)."";
				exit();				
			}
			/*
				order already refunded
			*/
			$order_results = WPPIZZA()->order->results_formatted('refund_gateway', $get_order['orders'][0], true);						
			if($order_results['sections']['ordervars']['payment_status']['value'] == 'REFUNDED'){
				$results['error'] = __('This order has already been refunded', 'wppizza-admin');	
				$results['error_message'] = 'Blog ID: '.$blog_id.' Order ID: '.$order_id;
				print"".json_encode($results)."";
				exit();				
			}			
			
			$transaction_id = $order_results['sections']['ordervars']['transaction_id']['value'];
			$total = $order_results['sections']['ordervars']['total']['value'];
			$order_details = $order_results['sections'];
			
			/**
				ini response
			**/
			$results = array();
		
			/**
				load class and refund
			**/
			$gateway = new $class;
			$method = $gateway->gatewayRefunds;
			$refund = $gateway->$method($order_id, $transaction_id, $total, $order_details);
			if($refund === true){
				$results['success'] = true;
				$results['success_message'] = __('Payment Refunded', 'wppizza-admin');
				
				
				/***************************************************************
					update order status with update timestamp
				****************************************************************/
				$update_db_values = array();
	
				/**
					amend order update
				**/
				$update_db_values['order_update'] 	= array('type'=> '%s', 'data' =>date('Y-m-d H:i:s', WPPIZZA_WP_TIME));
	
				/**
					set status, captured
				**/
				$update_db_values['order_status'] 	= array('type'=> '%s', 'data' => 'REFUNDED' );
	
				/**
					update payment status to refunded
				**/
				$update_db_values['payment_status'] 	= array('type'=> '%s', 'data' => 'REFUNDED' );
		
				/*
					run query
				*/
				$order_update = WPPIZZA()->db->update_order($blog_id, $order_id, false , $update_db_values );
	
	
				/**
					return new timestamp formatted to js
				**/
				$results['update_timestamp']= date("d-M-Y H:i:s",WPPIZZA_WP_TIME);
				$results['update_timestamp']= apply_filters('wppizza_filter_order_history_update_timestamp', $results['update_timestamp'], WPPIZZA_WP_TIME);
				
			}else{
				$results['error'] = __('Refund Failed', 'wppizza-admin');
				if(!empty($refund['error'])){
					$results['error_message'] = '';
					if(is_array($refund['error'])){
						foreach($refund['error'] as $k=>$e){
							$results['error_message'] .= ''.$k.': '.print_r($e, true);		
						}
					}else{
						$results['error_message'] .= ''.print_r($refund['error'], true);		
					}
				}
			}

			print"".json_encode($results)."";
		exit();
		}



		/********************************************
		*
		*
		*	[order history -> update order status]
		*
		*
		********************************************/
		if($_POST['vars']['field']=='orderstatuschange' && isset($_POST['vars']['id']) && $_POST['vars']['id']>=0){
			/**********set header********************/
			header('Content-type: application/json');


			/* 
				saving disabled 
			*/
			if(WPPIZZA_DEV_ADMIN_NO_SAVE){
				$obj['update_prohibited'] = __('Update Prohibited', 'wppizza-admin');
				print"".json_encode($obj)."";
			exit();
			}
			
			/*order id*/
			$order_id=(int)$_POST['vars']['id'];

			/*blog id*/
			$blog_id=(int)$_POST['vars']['blogid'];

			/****get oder status ***/
			$order_status=esc_sql($_POST['vars']['status']);

			/** not checking for payment_status as it mught previously been COMPLETED, REFUNDED, CANCELLED etc **/
			$payment_status = false;

			/****update payment status too if set to refunded***/
			//if($order_status=='REFUNDED'){
			//	$payment_status='REFUNDED';
			//}else{
				/**set back payment status if not refunded to what it was **/
			//	$payment_status='COMPLETED';
			//}

			/***************************************************************
				update order status with update timestamp
			****************************************************************/
			$update_db_values = array();

			/**
				amend order update
			**/
			$update_db_values['order_update'] 	= array('type'=> '%s', 'data' =>date('Y-m-d H:i:s', WPPIZZA_WP_TIME));

			/**
				set status, captured
			**/
			$update_db_values['order_status'] 	= array('type'=> '%s', 'data' => $order_status );

			/**
				update payment status too if set to refunded
			**/
			if($order_status=='REFUNDED' ){
				$update_db_values['payment_status'] 	= array('type'=> '%s', 'data' => $order_status );
			}

			/**
				set order delivered time if set as delivered
			**/
			if(in_array($order_status, unserialize(WPPIZZA_ADMIN_ORDER_DELIVERED_STATUS))){
				$update_db_values['order_delivered']= array('type'=> '%s', 'data' =>date('Y-m-d H:i:s', WPPIZZA_WP_TIME));
			}else{
				$update_db_values['order_delivered']= array('type'=> '%s', 'data' =>'0000-00-00 00:00:00');
			}

			/*
				run query
			*/
			$order_update = WPPIZZA()->db->update_order($blog_id, $order_id, false , $update_db_values, $payment_status );


			/**
				return new timestamp formatted to js
			**/
			$obj['update_timestamp']= date("d-M-Y H:i:s",WPPIZZA_WP_TIME);
			$obj['update_timestamp']= apply_filters('wppizza_filter_order_history_update_timestamp', $obj['update_timestamp'], WPPIZZA_WP_TIME);
			
			
			/*
				allow an action to run on order status change
			*/
			$obj['orderstatus_change_alert'] = '';/* ini as empty*/
			
			/*
				if filter has been added get order details
				and return alert as set 
			*/
			if(has_filter('wppizza_on_orderstatus_change')){
				/*********
					get entire order for this purchase
				*********/
				$order = WPPIZZA()->db->fetch_order_details($blog_id, $order_id, false, false, false);
				if(!empty($order)){
					/****************************************
					 order details are always arrays 
					*****************************************/
					$order = $order['orders'][0];
					/****************************************
						format parameters from order details
					****************************************/
					$order_formatted = WPPIZZA()->order->results_formatted('orderstatus_change', $order);					
					$blog_options = $order_formatted['blog_options'];

					/*****************************************
						add email plaintext template if id is set 
					******************************************/					
					$plaintext_template_id = apply_filters('wppizza_on_orderstatus_change_add_template', false);
					$plaintext_template = false;/* ini as false */
					if($plaintext_template_id >= 0 ){
						
						$template_type = 'emails';/* using emails templates */
						
						$template_options = get_option(WPPIZZA_SLUG.'_templates_'.$template_type, 0);/* get template options */
						
						if(!empty($template_options[$plaintext_template_id])){
							
							$template_values = $template_options[$plaintext_template_id];/* get template options for id */
							/* template array */
							$plaintext_template = WPPIZZA()->templates_email_print->get_template_email_plaintext_sections_markup($order_formatted, $blog_options['localization'], $template_values, $template_type );
							/* template markup */
							$plaintext_template = $plaintext_template['markup'];
						
						}
						
					}
					/* split results into some sensible arrays */
					$order_formatted = $order_formatted['sections'];
					
				}else{
					$blog_options = false;
					$plaintext_template = false;
					$order_formatted = false;
				}				
				
				/*
					return string to alert in js or return empty string for no alert
				*/
				$obj['orderstatus_change_alert'] = apply_filters('wppizza_on_orderstatus_change', $order_formatted, $order_status, $blog_options, $plaintext_template);				
			}
			

			print"".json_encode($obj)."";
			exit();
		}

		/********************************************
		*
		*
		*	[order history -> update custom]
		*
		*
		********************************************/
		if($_POST['vars']['field']=='customoptionchange' && isset($_POST['vars']['id']) && $_POST['vars']['id']>=0){
			/**********set header********************/
			header('Content-type: application/json');


			/* 
				saving disabled 
			*/
			if(WPPIZZA_DEV_ADMIN_NO_SAVE){
				$obj['update_prohibited'] = __('Update Prohibited', 'wppizza-admin');
				print"".json_encode($obj)."";
			exit();
			}

			/*order id*/
			$order_id=(int)$_POST['vars']['id'];

			/*blog id*/
			$blog_id=(int)$_POST['vars']['blogid'];

			/****get custom status ***/
			$custom_status=trim(esc_sql($_POST['vars']['status']));

			/***************************************************************
				update order status with update timestamp
			****************************************************************/
			$update_db_values = array();
			/** amend order update */
			$update_db_values['order_update'] 	= array('type'=> '%s', 'data' =>date('Y-m-d H:i:s', WPPIZZA_WP_TIME));
			/* set status, captured */
			$update_db_values['order_status_user_defined'] 	= array('type'=> '%s', 'data' => $custom_status );

			/* run query */
			$order_update = WPPIZZA()->db->update_order($blog_id, $order_id, false , $update_db_values );

			/**
				return new timestamp formatted to js
			**/
			$obj['update_timestamp']= date("d-M-Y H:i:s",WPPIZZA_WP_TIME);
			$obj['update_timestamp']= apply_filters('wppizza_filter_order_history_update_timestamp', $obj['update_timestamp'], WPPIZZA_WP_TIME);

			print"".json_encode($obj)."";
			exit();


		}
		/*****************************************************
		*
		*
		*	[order history -> delete order]
		*
		*
		*****************************************************/
		if($_POST['vars']['field']=='delete_order'){
			/**********set header********************/
			header('Content-type: application/json');
			
			/*
				check for delete capabilities
			*/
			if(!current_user_can('wppizza_cap_delete_order')){
				return;
			}

			/* 
				saving disabled 
			*/
			if(WPPIZZA_DEV_ADMIN_NO_SAVE){
				$obj['update_prohibited'] = __('Update Prohibited', 'wppizza-admin');
				print"".json_encode($obj)."";
			exit();
			}			
			

			/*blog_id*/
			$blog_id=(int)$_POST['vars']['blog_id'];

			/*order id*/
			$order_delete_id=(int)$_POST['vars']['order_id'];

			/* delete from db */
			$res = WPPIZZA()->db->delete_order($order_delete_id, $blog_id);

			$obj['feedback']="".__('order deleted', 'wppizza-admin')."";
			print"".json_encode($obj)."";
			exit();
		}
		/********************************************
		*
		*
		*		[order history -> update notes]
		*
		*
		********************************************/
		if($_POST['vars']['field']=='ordernoteschange' && isset($_POST['vars']['order_id']) && $_POST['vars']['order_id']>=0){
			/**********set header********************/
			header('Content-type: application/json');

			/* 
				saving disabled 
			*/
			if(WPPIZZA_DEV_ADMIN_NO_SAVE){
				$obj['update_prohibited'] = __('Update Prohibited', 'wppizza-admin');
				print"".json_encode($obj)."";
			exit();
			}


			/*blog_id*/
			$blog_id=(int)$_POST['vars']['blog_id'];

			/*order id*/
			$order_id=(int)$_POST['vars']['order_id'];

			/*add notes to db*/
			$notes=wppizza_validate_string($_POST['vars']['entered_notes']);
			$notes_length=strlen($notes);

			/***************************************************************
				update order notes and update timestamp
			****************************************************************/
			$update_db_values = array();
			/** amend order update */
			$update_db_values['order_update'] = array('type'=> '%s', 'data' =>date('Y-m-d H:i:s', WPPIZZA_WP_TIME));
			/* set status, captured */
			$update_db_values['notes'] 	= array('type'=> '%s', 'data' => $notes );
			/* run query */
			$order_update = WPPIZZA()->db->update_order($blog_id, $order_id, false , $update_db_values);


			/**get strlen of notes to show/hide things as required*/
			//$obj['notes_class'] = empty($notes_length) ? true : false ;
			$obj['notes_length'] = $notes_length;
			$obj['notes_button_label'] = empty($notes_length) ? __('add notes', 'wppizza-admin') :  __('view notes', 'wppizza-admin') ;
			$obj['notes_updated_alert'] =__('ok', 'wppizza-admin');
			$obj['update_timestamp']= date("d-M-Y H:i:s",WPPIZZA_WP_TIME);
			$obj['update_timestamp']= apply_filters('wppizza_filter_order_history_update_timestamp', $obj['update_timestamp'], WPPIZZA_WP_TIME);


			print"".json_encode($obj)."";
			exit();
		}
		/*************************************************************************************
		*
		*
		*	[order history -> print order]
		*
		*
		*************************************************************************************/
		if($_POST['vars']['field']=='print-order' && $_POST['vars']['id']>=0){
			/**********set header********************/
			header('Content-type: application/json');
			/*ini array for json*/
			$obj=array();

			/*order id*/
			$order_id=(int)$_POST['vars']['id'];
			/*blog_id*/
			$blog_id=(int)$_POST['vars']['blog_id'];
			/*template type*/
			$template_type='print';

			/****************************************
				get the order

			****************************************/
			$order = WPPIZZA()->db->fetch_order_details($blog_id, $order_id, false, array('COMPLETED','REFUNDED'), false);


			/****************************************
				no order exists that could be used
				as preview
			****************************************/
			if(empty($order)){
				$markup['str']="Error [AOH-101]:".__(' Sorry, this order does not exist.','wppizza-admin');
				print"".json_encode($markup)."";
				exit();
			}else{
				/** order details are always arrays */
				$order = $order['orders'][0];
			}
			/****************************************
				format parameters from order details
			****************************************/
			$order_parameters_formatted = WPPIZZA()->order->results_formatted('print_order', $order);


			/***************************************
				get selected template id and vars
			***************************************/
			global $wppizza_options;
			$template_id = $wppizza_options['templates_apply'][$template_type];

			/* default values  (-1) */
			$as_html = true;
			$template_values = false;

			/* saved template , anything != -1 */
			if($template_id != -1){
				/**get set print template options**/
				$template_options = get_option(WPPIZZA_SLUG.'_templates_'.$template_type,0);
				$template_options = apply_filters('wppizza_filter_template_options', $template_options, $template_type);
				$template_values = $template_options[$template_id];
				$as_html = ($template_values['mail_type'] == 'phpmailer') ?  true : false ;
			}

			/****************************************
				what size do we want to open the window
			****************************************/
			$obj['window-width'] = apply_filters('wppizza_filter_admin_print_window_width','750');
			$obj['window-height'] = apply_filters('wppizza_filter_admin_print_window_height','550');
			/****************************************
				object to return to ajax, content type
			****************************************/
			$obj['content-type'] = ($as_html) ? 'text/html' : 'text/plain';
			/****************************************
				get html or plaintext output
			****************************************/
			if($as_html){
				$obj['markup']['html'] = WPPIZZA()->templates_email_print->get_template_email_html_sections_markup($order_parameters_formatted, $order->blog_options['localization'], $template_values, $template_type );

			}else{
				/* plaintext returns sections too, so get the array first */
				$tpl = WPPIZZA()->templates_email_print->get_template_email_plaintext_sections_markup($order_parameters_formatted, $order->blog_options['localization'], $template_values, $template_type );
				$obj['markup']['plaintext'] = $tpl['markup'];
			}

			print"".json_encode($obj)."";
			exit();
		}
	}

	function order_history_results(){
		$order_history = json_decode($this->order_history_markup());
		echo $order_history -> markup;
	}
	/*********************************************************
	*
	*	[helper]
	* 	get orders markup
	*	@since 3.0
	*
	*********************************************************/
	function order_history_markup(){//$limit=false, $orderstatus='', $getparameters=false
		global $wppizza_options;
		$get_blog_url = get_bloginfo('url');

		/**
			array that knows if gateway has refunds enabled
		**/
		$gateway_refunds = array();
		
		/****
			get defaults or from GET vars (on pagination) or Ajax values
		****/
		if(empty($_POST['vars'])){
			$parsed_parameters = false;
			/* set queried order status, cast to uppercase to be safe */
			$status = empty($_GET['status']) ? false : strtoupper(wppizza_validate_alpha_only($_GET['status']));
			/* set queried custom status */
			$custom_status = empty($_GET['custom']) ? '' : esc_html(esc_sql($_GET['custom']));
			/* by user id */
			$uid = 	(isset($_GET['uid']) && is_numeric($_GET['uid'])) ? absint($_GET['uid']) : -1;
			$user_id = ($uid >=0 ) ? $uid : -1 ;
			/* limit per page - default here*/
			$lm = 	(isset($_GET['limit']) && is_numeric($_GET['limit'])) ? absint($_GET['limit']) : -1;
			$limit = ($lm >0 ) ? $lm  : apply_filters('wppizza_filter_order_history_max_results',25) ;
			/* paged*/
			$pg = !empty($_GET['paged']) ? absint($_GET['paged']) : 1 ;
			$paged = ($pg>0) ? $pg : 1;
		}else{
			/*parse parameters */
			$getparameters = $_POST['vars']['getparameters'];
			parse_str($getparameters, $parsed_parameters);


			/* set queried order status, cast to uppercase to be safe */
			$status = empty($_POST['vars']['status']) ? false : strtoupper(wppizza_validate_alpha_only($_POST['vars']['status']));
			/**add status parameter here to pass on as get var if set*/
			if(!empty($status)){
				$parsed_parameters['status']=$status;
			}else{
				unset($parsed_parameters['status']);
			}

			/* set queried custom status */
			$custom_status = empty($_POST['vars']['custom']) ? '' : esc_html(esc_sql($_POST['vars']['custom']));
			if(!empty($custom_status)){
				$parsed_parameters['custom']=$custom_status;
			}else{
				unset($parsed_parameters['custom']);
			}


			/* by user id */
			$uid = 	(isset($parsed_parameters['uid']) && is_numeric($parsed_parameters['uid']) )? absint($parsed_parameters['uid']) : -1;
			$user_id = ($uid >=0 ) ? $uid : -1 ;

			/* limit per page - according to entered int*/
			$abs_limit = absint($_POST['vars']['limit']);/* cast to var for php 5.3 */
			$order_history_max_results = apply_filters('wppizza_filter_order_history_max_results',25);/* cast to var for php 5.3 */
			$limit = empty($abs_limit) ? $order_history_max_results : $abs_limit;
			/**add limit parameter here to pass on as get var if set*/
			if(!empty($limit)){
				$parsed_parameters['limit']=$limit;
			}else{
				unset($parsed_parameters['limit']);
			}


			/* paged*/
			$pg = !empty($parsed_parameters['paged']) ? absint($parsed_parameters['paged']) : 1 ;
			$paged = ($pg>0) ? $pg : 1;


			/**always unset user id when using ajax**/
			//unset($parsed_parameters['uid']);
		}

		/********************************************************************
			get orders
			returns total count as well as paginated orders on page
		********************************************************************/
		$orders = WPPIZZA() -> db -> get_orders_orderhistory($status, $user_id, $limit, $paged, $custom_status);
		/********************************************************************

			get pagination

		********************************************************************/
		$pagination = WPPIZZA()->admin_helper->admin_pagination($orders['total_orders'], $limit, $parsed_parameters);

		/****
			get gateway idents transforming to set label
		****/
		foreach($orders['gateways_idents'] as $gwIdent){
			$gateway_options=get_option(strtolower(WPPIZZA_SLUG.'_gateway_'.$gwIdent),0);
			if($gateway_options!=0){
				$gateway_label[strtoupper($gwIdent)]=!empty($gateway_options['_gateway_label']) ? $gateway_options['_gateway_label'] : strtoupper($gwIdent) ;
			}else{
				$gateway_label[strtoupper($gwIdent)]=strtoupper($gwIdent);
			}
		}

		/****

			pagination counts markup

		****/
		$markup_pagination_info = array();
		$markup_pagination_info['span_left'] = '<span class="'.WPPIZZA_SLUG.'-pagination-left">'.$pagination['on_page'].' '.__('of','wppizza-admin').' '.$pagination['total_count'].'</span>';
		$markup_pagination_info['span_right'] = '<span class="'.WPPIZZA_SLUG.'-pagination-right">'.$pagination['pages'] .'</span>';
		/**
			allow filtering of pagination_info
		**/
		$markup_pagination_info = apply_filters('wppizza_filter_orderhistory_pagination_info', $markup_pagination_info, $pagination);
		$markup_pagination_info =implode('',$markup_pagination_info);

		/****

			header/footer markup

		****/
		$markup_header_footer = array();

		$markup_header_footer['tr_'] = "<tr>";

			/*
				first header column
			*/
			$markup_header_footer['th_1_'] = "<th scope='col' class='manage-column ".WPPIZZA_SLUG."-".$this->section_key."-column-left'>";
				$markup_header_footer['th_1_order'] = __('Summary','wppizza-admin');
			$markup_header_footer['_th_1'] = "</th>";


			/*
				second header column
			*/
			$markup_header_footer['th_2_'] = "<th scope='col' class='manage-column ".WPPIZZA_SLUG."-".$this->section_key."-column-order'>";
				if($status!='FAILED'){
					$markup_header_footer['th_2_customer_details'] = __('Order Details','wppizza-admin');
				}else{
					$markup_header_footer['th_2_tx_error_details'] = __('Error Details','wppizza-admin');
				}
			$markup_header_footer['_th_2'] = "</th>";


			/*
				third header column
			*/

			$markup_header_footer['th_3_'] = "<th scope='col' class='manage-column ".WPPIZZA_SLUG."-".$this->section_key."-column-right'>";
				$markup_header_footer['th_3_value'] = "".__('Value','wppizza-admin')." ".wppizza_format_price($orders['value_orders_on_page'])."";
			$markup_header_footer['_th_3'] = "</th>";

		$markup_header_footer['_tr'] = "</tr>";
		/**
			allow filtering of header footer markup
		**/
		$markup_header_footer = apply_filters('wppizza_filter_orderhistory_header_footer', $markup_header_footer, $orders, $status);
		$markup_header_footer =implode('',$markup_header_footer);


		/**************************************************************************************
		*
		*
		*
		*	markup of orders and pagination to return/output
		*
		*
		*
		**************************************************************************************/
		$markup=array();

			/*
				if we are only displaying for a distinct user id,
				make this clear here

			*/
			if($user_id>0){
				$user_data = get_userdata($user_id);
				$markup['history_user_info'] = '<h2 id="'.WPPIZZA_SLUG.'_'.$this->section_key.'_user-info">'.sprintf(__('Orders for user "%s"', 'wppizza-admin'), print_r($user_data->user_login, true)).'</h2>';
			}


			/**
				pagination top
			**/
			$markup['pagination_top']='<div class="widefat '.WPPIZZA_SLUG.'-pagination '.WPPIZZA_SLUG.'-pagination-top">';
				$markup['pagination_top'].=$markup_pagination_info;
			$markup['pagination_top'].='</div>';


			/**
				orders table
			**/
			$markup['orders_table_']="<table id='".WPPIZZA_SLUG."_list_".$this->section_key."' class='widefat fixed striped'>";
				/**
					orders table header
				**/
				$markup['thead']="<thead>";
					/**add header footer markup to output */
					$markup['thead'].=$markup_header_footer;
				$markup['thead'].="</thead>";

				/**
					orders table footer
				**/
				$markup['tfoot']="<tfoot>";
					$markup['tfoot'].=$markup_header_footer;
				$markup['tfoot'].="</tfoot>";


				/**
					the orders
				**/
				$markup['tbody_']="<tbody id='the-list'>";

				/*no orders*/
				if(count($orders['orders'])<=0){
					$markup['tbody_no_results']="<tr><td colspan='4' id='".WPPIZZA_SLUG."-".$this->section_key."-no-orders'>".__('no results found','wppizza-admin')."</td></tr>";
				}






				if(count($orders['orders'])>0){
				foreach($orders['orders'] as $order){
					
					
					/**
						check if gateway has refunds enabled
						and has delete capabilities
					**/
					$gateway_ident = $order['initiator'];
					if(!isset($gateway_refunds[$gateway_ident]) && current_user_can('wppizza_cap_delete_order')){
						$gw_class = 'WPPIZZA_GATEWAY_'.$gateway_ident.'';					
						if (class_exists( $gw_class )){
							$gw = new $gw_class();
														
							$gw_allows_refunds = !empty($gw->gatewayRefunds) ? $gw->gatewayRefunds : false ;
							/*
								set gw name and refund method
							*/
							$gateway_refunds[$gateway_ident] = array('name' => $gw->gatewayName , 'classname' => $gw_class ,'method' => $gw_allows_refunds);
						}
					}

					/**
						if payment status failed , override order status class
					**/
					$order_status_class=$order['order_status'];
					if($order['payment_status']=='failed'){
						$order_status_class='failed';
					}
					/**
						payment status unconfirmed, add class
					**/					
					$payment_unconfirmed_class = ($order['payment_status']=='unconfirmed') ? " ".WPPIZZA_SLUG."-".$this->section_key."-payment-unconfirmed" : "" ;					
					
					/**
						add/apply filters to individual variables where required
						and any variables/markup we want to  re-use in multiple places
					**/
					/**allow filtering/formatting. supply current time too for servers where php.ini timezone is incorrectly set*/
					$order['order_date']= apply_filters('wppizza_filter_order_history_order_timestamp', $order['order_date'], strtotime($order['order_date'], WPPIZZA_WP_TIME));
					/* order delivered */
					$order['order_delivered']= apply_filters('wppizza_filter_order_history_order_timestamp', $order['order_delivered'], strtotime($order['order_delivered'], WPPIZZA_WP_TIME));
					/* order transation id */
					$order['transaction_id']= apply_filters('wppizza_filter_transaction_id',$order['transaction_id'], $order['id']);
					
					
					/**allow filtering/formatting. synchronous in line with js result when changing order status - supply current time too for servers where php.ini timezone is incorrectly set*/
					$cast_order_update = (int)$order['order_update'];/* simply cast date to integer to check if it's zero */
					$order_update=!empty($cast_order_update) ? ''.$order['order_update'] : $order['order_date'] ;
					$order_update= apply_filters('wppizza_filter_order_history_update_timestamp', $order_update, strtotime($order_update, WPPIZZA_WP_TIME));



					/******************************
					*
					*	thickbox
					*	needs double div wrapping to be able to style
					*
					*******************************/
					$orderthickbox=array();
					$orderthickbox['div_']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-thickbox-".$order['uoKey']."' style='display:none'><div class='".WPPIZZA_SLUG."-".$this->section_key."-thickbox'>";

					if($order['payment_status']!='failed'){
						$orderthickbox['order_status']="<pre class='".WPPIZZA_SLUG."-".$this->section_key."-thickbox-order_status'><span>".__('Status', 'wppizza-admin')." ".WPPIZZA()->admin_helper->orderhistory_order_status_select($this->section_key, 'thickbox', $order['uoKey'], $order['order_status'])."</span></pre>";
						$orderthickbox['customer_details']="<pre class='".WPPIZZA_SLUG."-".$this->section_key."-thickbox-customer_details'>".$order['customer_details']."</pre>";
						$orderthickbox['order_details']="<pre class='".WPPIZZA_SLUG."-".$this->section_key."-thickbox-order_details'>".$order['order_details']."</pre>";
					}else{
						/*sanitize for output*/
						$transaction_errors=WPPIZZA()->admin_helper->unserialize_errors_to_string($order['transaction_errors']);
						$mail_errors=WPPIZZA()->admin_helper->unserialize_errors_to_string($order['mail_error']);
						$orderthickbox['transaction_errors']="<pre class='".WPPIZZA_SLUG."-".$this->section_key."-thickbox-transaction_errors'>".$transaction_errors."</pre>";
						$orderthickbox['mail_errors']="<pre class='".WPPIZZA_SLUG."-".$this->section_key."-thickbox-mail_errors'>".$mail_errors."</pre>";
					}
					$orderthickbox['_div']="</div></div>";

					/**allow filtering**/
					$orderthickbox= apply_filters('wppizza_filter_orderhistory_thickbox', $orderthickbox, $order);
					$orderthickbox=implode('',$orderthickbox);


					/**
						add visible/hidden class to summary/full details depending on status
					**/
					$summary_visibility_status=WPPIZZA()->admin_helper->orderhistory_summary_visibility_by_status();
					/*class and dashicons*/
					$summary_visibility_class='';
					//$summary_visibility_dashicon='';
					$details_visibility_class='';
					//$details_visibility_dashicon='';
					if(in_array($order['order_status'],$summary_visibility_status)){
						$summary_visibility_class="".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-active";
						$details_visibility_class="".WPPIZZA_SLUG."-".$this->section_key."-orderdetails-inactive";
					}

					/**
						ini new empty array for this order
					**/
					$order_markup = array();


					/****************************************************************************
					*
					*
					*	[first row -> summary - only shown if delivered]
					*
					*
					****************************************************************************/
					/*open tr*/
					$order_markup['summary_tr_'] = "<tr id='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary ".WPPIZZA_SLUG."-".$this->section_key."-orderstatus-".$order_status_class."".$payment_unconfirmed_class." ".$summary_visibility_class."'>";


						/***************************************************************
						*
						*	first row, first column,
						*	summary transaction info
						*
						****************************************************************/
						$order_markup['summary_info_td_'] ="<td  id='".WPPIZZA_SLUG."-".$this->section_key."-column-details-summary-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-column-details-summary'>";


							$ordersummary_info=array();

							/******************************
							*
							*	multisite, blog info if exists, appropriate
							*
							*******************************/
							if(!empty($order['blogname'])){
								$ordersummary_info['blogname']= "<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-blogname'>".$order['blogname']."</span>";
							}
							/******************************
							*
							*	order date
							*
							*******************************/
							$ordersummary_info['order_date']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-order_date'>".$order['order_date']."</span>";

							/******************************
							*
							*	get used gateway label
							*
							*******************************/
							$ordersummary_info['payment']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-payment'>".__('Payment By', 'wppizza-admin').": ". $gateway_label[$order['initiator']] ."</span>";

							/******************************
							*
							*	status
							*
							*******************************/
							$ordersummary_info['status']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-status'>".__('Status', 'wppizza-admin').": ". wppizza_order_status_default(false,$order['order_status']) ."</span>";

							/******************************
							*
							*	unconfirmed
							*
							*******************************/
							if($order['payment_status']=='unconfirmed'){
								$ordersummary_info['unconfirmed']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-unconfirmed'>".__('Unconfirmed Payment', 'wppizza-admin')."</span>";
							}

							/******************************
							*
							*	delivered time
							*
							*******************************/
							if($order['order_status'] == 'delivered' && !empty($order['order_delivered'])){
								$ordersummary_info['order_delivered']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-order_delivered'>".__('On', 'wppizza-admin').": ". $order['order_delivered'] ."</span>";
							}

							/******************************
							*
							*	custom status
							*
							*******************************/
							if($wppizza_options['localization']['order_history_custom_status_options'] !='' && $order['order_status_user_defined']!=''){
								$ordersummary_info['custom_status']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-order_status_user_defined'>".$wppizza_options['localization']['order_history_custom_status_label']." ".$order['order_status_user_defined']."</span>";
							}

							/**allow filtering**/
							$ordersummary_info = apply_filters('wppizza_filter_orderhistory_ordersummary_info', $ordersummary_info, $order);
							$order_markup['summary_info']='<div>'.implode('<br />',$ordersummary_info).'</div>';

							///******************************
							//*
							//*	collapse/expand dashicon - absolute positioned
							//*
							//*******************************/
							//if(!empty($summary_visibility_dashicon)){
							//$markup.= !empty($summary_visibility_dashicon) ? $summary_visibility_dashicon : '';
							//}

						$order_markup['_summary_info_td']="</td>";

						/***************************************************************
						*
						*	first row, second column,
						*	summary order info
						*
						****************************************************************/
						$order_markup['summary_td_']="<td  id='".WPPIZZA_SLUG."-".$this->section_key."-column-order-summary-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-column-order-summary'>";

							/**get enabled formfields and display first 4 non-empty, non-textarea lines **/
							$formfields=WPPIZZA()->admin_helper->admin_orderform_enabled_formfields('orderhistory');
							$ordersummary_customer=array();
							$count=0;
							/*custom define limit if required*/
							$limit=apply_filters('wppizza_filter_orderhistory_summary_max_lines_cdetails', 4);
							foreach($formfields as $ffKey=>$ff){
								/*this is a summary only, so omit textareas, empty values and limit to first 4 (or filtered) lines only*/
								if($ff!='textarea' && !empty($order['customer_ini'][$ffKey])){
									if($count>=$limit){break;}
									/* implode if array (multicheckboxes) */
									$customer_value = is_array($order['customer_ini'][$ffKey]) ? implode(', ',$order['customer_ini'][$ffKey]) : $order['customer_ini'][$ffKey];
									$ordersummary_customer[$ffKey] = "<span>".$ff['lbl'] . ' ' .$customer_value ."</span>";

									$count++;
								}
							}
							/**allow filtering**/
							$ordersummary_customer = apply_filters('wppizza_filter_orderhistory_ordersummary_customer', $ordersummary_customer, $order);
							$order_markup['summary_customer']="<div class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-customer'>".implode('',$ordersummary_customer)."</div>";


						/***************************************************************
						*
						*	first row, second column,
						*	summary order info
						*
						****************************************************************/

							$ordersummary_order=array();

							/******************************
							*
							*	no of items
							*
							*******************************/
							$ordersummary_order['items']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-items'>".__('Items','wppizza-admin')." [".$order['order_no_of_items']."]: ".wppizza_format_price($order['order_items_total'],$order['currency'])."</span>";
							/******************************
							*
							*	discounts
							*
							*******************************/
							if(!empty($order['order_discount'])){
								$ordersummary_order['discount']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-discount'>".__('Discount','wppizza-admin').": -".wppizza_format_price($order['order_discount'],$order['currency']) ."</span>";
							}
							/******************************
							*
							*	taxes - only show added here (for now) so the total sum correlates
							*
							*******************************/
							if(!empty($order['order_taxes']) && $order['order_taxes_included'] == 'N'){
								$taxes_included = ($order['order_taxes_included'] == 'Y') ? ' ['.__('Included','wppizza-admin').']' : '' ;
								$ordersummary_order['taxes']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-taxes'>".__('Taxes','wppizza-admin').": ".wppizza_format_price($order['order_taxes'],$order['currency']) ."".$taxes_included."</span>";
							}
							/******************************
							*
							*	Shipping/Handling
							*
							*******************************/
							if(!empty($order['order_delivery_charges']) || !empty($order['order_handling_charges']) ){
								$delivery=empty($order['order_delivery_charges']) ? '' : ''.__('Delivery','wppizza-admin').': '.wppizza_format_price($order['order_delivery_charges'],$order['currency']);


								if(empty($order['order_delivery_charges'])){/* no devider if no delivery charges */
									$handling=empty($order['order_handling_charges']) ? '' : __('Handling','wppizza-admin').': '.wppizza_format_price($order['order_handling_charges'],$order['currency']);
								}else{
									$handling=empty($order['order_handling_charges']) ? '' : ' | '.__('Handling','wppizza-admin').': '.wppizza_format_price($order['order_handling_charges'],$order['currency']);
								}

								$ordersummary_order['delivery_handling']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-delivery_handling'>". $delivery ."  ". $handling ."</span>";
							}
							if(empty($order['order_delivery_charges']) && $order['order_self_pickup']=='N'){
								$ordersummary_order['free_delivery']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-free_delivery'>".__('Free Delivery','wppizza-admin')."</span>";
							}
							/******************************
							*
							*	pickup
							*
							*******************************/
							if($order['order_self_pickup']=='Y'){
								$ordersummary_order['pickup']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-self-pickup'>".__('pickup by customer','wppizza-admin')."</span>";
							}
							/******************************
							*
							*	tips
							*
							*******************************/
							if(!empty($order['order_tips'])){
								$ordersummary_order['tips']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-tips'>".__('Tips','wppizza-admin').": ".wppizza_format_price($order['order_tips'],$order['currency']) ."</span>";
							}
							/******************************
							*
							*	total
							*
							*******************************/
							$ordersummary_order['total']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-total'>".__('Total','wppizza-admin').": ".wppizza_format_price($order['order_total'],$order['currency']) ."</span>";


							/**allow filtering**/
							$ordersummary_order= apply_filters('wppizza_filter_orderhistory_ordersummary_order', $ordersummary_order, $order);
							$order_markup['summary_order']="<div class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-order'>".implode('',$ordersummary_order)."</div>";



						$order_markup['_summary_td']="</td>";

						/***************************************************************
						*
						*	first row, third column,
						*	summary actions (user id/guest)
						*
						****************************************************************/
						$order_markup['summary_actions_td_']="<td id='".WPPIZZA_SLUG."-".$this->section_key."-column-actions-summary-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-column-actions-summary'>";

							$ordersummary_actions=array();
							/******************************
							*
							*	userid/guest
							*
							*******************************/
							if(!empty($order['wp_user_id'])){
								$ordersummary_actions['wp_user_id']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-wp_user_id'>			<a href='".$get_blog_url."/wp-admin/edit.php?post_type=".WPPIZZA_POST_TYPE."&page=customers&s=".$order['wp_user_id']."' class='".WPPIZZA_SLUG."-dashicons dashicons-businessman' title='".__('User Id', 'wppizza-admin').": ".$order['wp_user_id']."'></a></span>";
								$ordersummary_actions['wp_user_id'].="<span class='".WPPIZZA_SLUG."-".$this->section_key."-ordersummary-wp_user_id-orders'>	<a href='".$get_blog_url."/wp-admin/edit.php?post_type=".WPPIZZA_POST_TYPE."&page=".$this->section_key."&uid=".$order['wp_user_id']."' class='".WPPIZZA_SLUG."-dashicons dashicons-chart-line' title='".__('Show orders for user', 'wppizza-admin').": ".$order['wp_user_id']."'></a></span>";
							}else{
								$ordersummary_actions['wp_user_id']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-wp_user_guest'><a class='".WPPIZZA_SLUG."-dashicons dashicons-admin-users' title='".__('Guest', 'wppizza-admin')."'></a>".__('Guest', 'wppizza-admin')."</span>";
							}

							/**allow filtering**/
							$ordersummary_actions= apply_filters('wppizza_filter_orderhistory_ordersummary_actions', $ordersummary_actions, $order);
							$order_markup['summary_actions']=implode('<br />',$ordersummary_actions);

						$order_markup['_summary_actions_td']="</td>";
					/*close tr*/
					$order_markup['_summary_tr'] = "</tr>";


					/****************************************************************************
					*
					*
					*	[second row -> details - shown if != delivered]
					*
					*
					****************************************************************************/
					$order_markup['details_tr_'] = "<tr id='".WPPIZZA_SLUG."-".$this->section_key."-order-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-orderdetails ".WPPIZZA_SLUG."-".$this->section_key."-orderstatus-".$order_status_class."".$payment_unconfirmed_class."  ".$details_visibility_class."'>";


						/***************************************************************
						*
						*	second row, first column,
						*	order info (id, transaction id etc)
						*
						****************************************************************/
						$order_markup['details_info_td_']="<td id='".WPPIZZA_SLUG."-".$this->section_key."-column-details-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-column-details'>";


								$orderdetails_info=array();

								/******************************
								*
								*	multisite, blog info if exists, appropriate
								*
								*******************************/
								if(!empty($order['blogname'])){
									$orderdetails_info['blogname']= "<span id='".WPPIZZA_SLUG."-".$this->section_key."-order-blogname-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-order-blogname'>".$order['blogname']."</span>";
								}
								/******************************
								*
								*	order date
								*
								*******************************/
								$orderdetails_info['date']= "<span id='".WPPIZZA_SLUG."-".$this->section_key."-order-date-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-order-date'>".$order['order_date']."</span>";

								/******************************
								*
								*	get used gateway label
								*
								*******************************/
								$orderdetails_info['payment']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-payment'>".__('Payment By', 'wppizza-admin').": <span id='".WPPIZZA_SLUG."-".$this->section_key."-order-payment-".$order['uoKey']."'>". $gateway_label[$order['initiator']] ."</span></span>";


								/******************************
								*
								*	transaction_id
								*
								*******************************/
								if(!empty($order['transaction_id'])){
									$orderdetails_info['transaction_id']="<span id='".WPPIZZA_SLUG."-".$this->section_key."-order-txid-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-order-txid'>".$order['transaction_id']."</span>";
								}


								/****************************
								*
								*	print order status dropdown if not failed or unconfirmed 
								*
								****************************/
								/**
									dropdown only if not failed
								**/
								if($order['payment_status']!='failed'){

									$orderdetails_info['status']="<span>".__('Status', 'wppizza-admin')." ";
									/**dropdown*/
										$orderdetails_info['status'].=WPPIZZA()->admin_helper->orderhistory_order_status_select($this->section_key, 'details', $order['uoKey'], $order['order_status']);
									$orderdetails_info['status'].="</span>";
								}
								/**
									static label if failed
								**/
								if($order['payment_status']=='failed'){
									$orderdetails_info['status']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-status-failed'>".__('Status', 'wppizza-admin').": ".__('Failed','wppizza-admin')."</span>";
								}

								/**
									add static unconfirmed label if unconfirmed
								**/
								if($order['payment_status']=='unconfirmed'){
									$orderdetails_info['status'].="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-status-unconfirmed'>".__('Unconfirmed Payment', 'wppizza-admin')."</span>";
								}

								/**custom options **/
								if($wppizza_options['localization']['order_history_custom_status_options'] !='' ){
									$orderdetails_info['custom_status']="<span>".$wppizza_options['localization']['order_history_custom_status_label']." ";
									/**dropdown*/
									$orderdetails_info['custom_status'].=WPPIZZA()->admin_helper->orderhistory_custom_options_select($this->section_key, 'details', $order['uoKey'], $order['order_status_user_defined'], false);

									$orderdetails_info['custom_status'].="</span>";
								}
								
								
								/******************************
								*
								*	refunds
								*
								*******************************/
								if(!empty($gateway_refunds[$order['initiator']]['method'])){
									$orderdetails_info['refund'] = "<div id='".WPPIZZA_SLUG."-".$this->section_key."-refund-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-refund'>";
										$orderdetails_info['refund'] .= "<label class='".WPPIZZA_SLUG."-".$this->section_key."-enable-refund-label'>";
										$orderdetails_info['refund'] .= "<input type='checkbox' class='".WPPIZZA_SLUG."-".$this->section_key."-enable-refund' value='".$gateway_refunds[$order['initiator']]['classname']."' />";
										$orderdetails_info['refund'] .= sprintf(__('Refund in %s', 'wppizza-admin'), $gateway_refunds[$gateway_ident]['name']);
										$orderdetails_info['refund'] .= "</label>";
										$orderdetails_info['refund'] .= " <input type='button' id='".WPPIZZA_SLUG."-".$this->section_key."-process-refund-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-process-refund' value='".__('OK', 'wppizza-admin')."' />";
									$orderdetails_info['refund'] .= "</div>";
								}								
								
								
								/******************************
								*
								*	order update . empty if still
								*	0000-00-00 00:00:00
								*
								*******************************/
								$orderdetails_info['order_update'] ="<span id='".WPPIZZA_SLUG."-".$this->section_key."-order-update-".$order['uoKey']."'>".__('Updated', 'wppizza-admin').": <span id='".WPPIZZA_SLUG."-".$this->section_key."-order-update-".$order['uoKey']."-time'>".$order_update."</span>";

								/**allow filtering**/
								$orderdetails_info= apply_filters('wppizza_filter_orderhistory_order_info', $orderdetails_info, $order);
								$order_markup['details_info']=''.implode('',$orderdetails_info).'';// brs set by display:block

								///******************************
								//*
								//*	collapse/expand dashicon - absolute positioned
								//*
								//*******************************/
								//if(!empty($details_visibility_dashicon)){
								//	$markup.= $details_visibility_dashicon;
								//}


						$order_markup['_details_info_td'] = "</td>";


						/***************************************************************
							second row, second column,
							order details or error details on failed
						****************************************************************/
						$order_markup['details_order_td_']="<td id='".WPPIZZA_SLUG."-".$this->section_key."-column-order-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-column-order'>";

							/*
								customer details
							*/
							$orderdetails_customer=array();

							/**non failed*/
							if($order['payment_status']!='failed'){
								$orderdetails_customer['customer_details']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-customer-pre-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-pre ".WPPIZZA_SLUG."-".$this->section_key."-do-thickbox'><pre>".$order['customer_details']."</pre></div>";
							}

							/**failed*/
							if($order['payment_status']=='failed'){
								/*sanitize for output*/
								$transaction_errors = WPPIZZA()->admin_helper->unserialize_errors_to_string($order['transaction_errors']);
								$orderdetails_customer['transaction_errors']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-customer-pre-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-pre'><pre>".$transaction_errors."</pre></div>";
							}

							/**allow filtering**/
							$orderdetails_customer= apply_filters('wppizza_filter_orderhistory_order_customer', $orderdetails_customer, $order);
							$order_markup['details_customer']=implode('<br />',$orderdetails_customer);


							/*
								order details
							*/
							$orderdetails_order=array();

							/**non failed*/
							if($order['payment_status']!='failed'){
								$orderdetails_order['order_details']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-order-pre-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-pre ".WPPIZZA_SLUG."-".$this->section_key."-do-thickbox'><pre>".$order['order_details']."</pre></div>";
							}
							/**failed*/
							if($order['payment_status']=='failed'){
								/*sanitize for output*/
								$mail_errors=WPPIZZA()->admin_helper->unserialize_errors_to_string($order['mail_error']);
								$orderdetails_order['mail_errors']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-order-pre-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-pre'><pre>".$mail_errors."</pre></div>";
							}

							if($order['payment_status']=='failed'){
							$order_markup['show_details_button']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-viewfailed-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-viewfailed ".WPPIZZA_SLUG."-".$this->section_key."-do-thickbox button'>".__('view details', 'wppizza-admin')."</div>";
							}else{
							$order_markup['show_details_button']="<div id='".WPPIZZA_SLUG."-".$this->section_key."-vieworder-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-vieworder ".WPPIZZA_SLUG."-".$this->section_key."-do-thickbox button'>".__('view order', 'wppizza-admin')."</div>";
							}
							/**allow filtering**/
							$orderdetails_order= apply_filters('wppizza_filter_orderhistory_order_details', $orderdetails_order, $order);
							$order_markup['details_order']=implode('<br />',$orderdetails_order);


						$order_markup['_details_order_td']="</td>";


						/***************************************************************
							second row, fourth column,
							delete, print, add notes
						****************************************************************/
						$order_markup['details_actions_td_']="<td id='".WPPIZZA_SLUG."-".$this->section_key."-column-actions-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-column-actions'>";

							$orderdetails_actions=array();
							/******************************
							*
							*	delete order button [admin only]
							*
							******************************/
							if (current_user_can('wppizza_cap_delete_order')){
								$orderdetails_actions['delete']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-delete_order'><a href='javascript:void(0)' id='".WPPIZZA_SLUG."-".$this->section_key."-delete-order-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-delete-order ".WPPIZZA_SLUG."-dashicons dashicons-trash' title='".__('delete order', 'wppizza-admin')."'></a></span>";

							}
							/************************
							*
							*	print order button
							*
							************************/
							$orderdetails_actions['print']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-print_order'><a href='javascript:void(0);'  id='".WPPIZZA_SLUG."-".$this->section_key."-print-order-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-print-order ".WPPIZZA_SLUG."-dashicons dashicons-media-document' title='".__('print order', 'wppizza-admin')."'></a></span>";

							/******************************
							*
							*	userid/guest
							*
							*******************************/
							if(!empty($order['wp_user_id'])){
								$orderdetails_actions['wp_user_id']="<span>";
								$orderdetails_actions['wp_user_id'].="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-wp_user_id'><a href='".$get_blog_url."/wp-admin/edit.php?post_type=".WPPIZZA_POST_TYPE."&page=customers&s=".$order['wp_user_id']."' class='".WPPIZZA_SLUG."-dashicons dashicons-businessman' title='".__('User Id', 'wppizza-admin').": ".$order['wp_user_id']."'></a></span>";
								$orderdetails_actions['wp_user_id'].="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-wp_user_id-orders'><a href='".$get_blog_url."/wp-admin/edit.php?post_type=".WPPIZZA_POST_TYPE."&page=".$this->section_key."&uid=".$order['wp_user_id']."' class='".WPPIZZA_SLUG."-dashicons dashicons-chart-line' title='".__('Show orders for user', 'wppizza-admin').": ".$order['wp_user_id']."'></a></span>";
								$orderdetails_actions['wp_user_id'].="</span>";
							}else{
								$orderdetails_actions['wp_user_id']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-wp_user_guest'><a class='".WPPIZZA_SLUG."-dashicons dashicons-admin-users' title='".__('Guest', 'wppizza-admin')."'></a>".__('Guest', 'wppizza-admin')."</span>";
							}

							/************************
							*
							*	add/edit notes button
							*
							************************/
							if(trim($order['notes'])==''){
								$view_add_notes_label=__('add notes', 'wppizza-admin');
								$order_has_notes_class='';
							}else{
								$view_add_notes_label=__('view notes', 'wppizza-admin');
								$order_has_notes_class="".WPPIZZA_SLUG."-".$this->section_key."-order-has-notes";
							}
							$orderdetails_actions['notes']="<span class='".WPPIZZA_SLUG."-".$this->section_key."-order-add_notes'><a href='javascript:void(0);'  id='".WPPIZZA_SLUG."-".$this->section_key."-order-view-add-notes-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-order-view-add-notes ".$order_has_notes_class." button'>".$view_add_notes_label."</a></span>";


							/**
								allow filtering
							**/
							$orderdetails_actions = apply_filters('wppizza_filter_orderhistory_order_actions', $orderdetails_actions, $order);
							$order_markup['details_actions']=implode('',$orderdetails_actions);

						$order_markup['_details_actions_td']="</td>";

					$order_markup['_details_tr'] = "</tr>";


					/****************************************************************************
					*
					*
					*	[third row -> order notes and thickbox]
					*
					*
					****************************************************************************/
					$order_markup['notes_tr_'] = "<tr id='".WPPIZZA_SLUG."-".$this->section_key."-order-notes-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-order-notes'>";
						$order_markup['notes_td_']="<td colspan='3'>";

							$orderdetails_notes=array();
							/**
								notes
							**/
							$orderdetails_notes['textarea_notes']="<textarea id='".WPPIZZA_SLUG."-".$this->section_key."-notes-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-notes' placeholder='".__('notes:', 'wppizza-admin')."'>".$order['notes']."</textarea>";
							$orderdetails_notes['textarea_notes_ok']="<a href='javascript:void(0);'  id='".WPPIZZA_SLUG."-".$this->section_key."-do-notes-".$order['uoKey']."' class='".WPPIZZA_SLUG."-".$this->section_key."-do-notes button'>".__('ok', 'wppizza-admin')."</a>";
							/**
								allow filtering
							**/
							$orderdetails_notes= apply_filters('wppizza_filter_orderhistory_order_notes', $orderdetails_notes, $order);
							$order_markup['notes']=implode('',$orderdetails_notes);


							/******************************
							*
							*	thickbox div
							*
							*******************************/
							$order_markup['order_thickbox']=$orderthickbox;

						$order_markup['_notes_td']="</td>";
					$order_markup['_notes_tr'] = "</tr>";

					/****************************************************************************
					*
					*	[implode for output]
					*
					****************************************************************************/
					$markup['order_'.$order['uoKey']] = implode('',$order_markup);
				}}
				
				/**********************************
					end order
				**********************************/

				$markup['_tbody']="</tbody>";

			$markup['_orders_table']='</table>';

			/**
				pagination bottom
			**/
			$markup['pagination_bottom']='<div class="widefat '.WPPIZZA_SLUG.'-pagination '.WPPIZZA_SLUG.'-pagination-bottom">';
				$markup['pagination_bottom'].=$markup_pagination_info;
			$markup['pagination_bottom'].='</div>';

		/**
			allow filtering of entire markup
		**/
		$markup= apply_filters('wppizza_filter_orderhistory_markup', $markup);
		$markup=implode('',$markup);

		/*
			return object containing markup
			and raw parameters
		*/
		$results = array();
		$results['markup'] = $markup;
		$results['values'] = $orders;

	return json_encode($results);
	}

}
/***************************************************************
*
*	[ini]
*
***************************************************************/
$WPPIZZA_MODULE_ORDERHISTORY_ORDERHISTORY = new WPPIZZA_MODULE_ORDERHISTORY_ORDERHISTORY();
?>